@@ -10,7 +10,6 @@ class HTTPClientWriter(object):
     def dispatch(self, request, cb, args):
         request.headers['Host'] = self.conn.addr[0]
         self.conn.write(request.render(), self.__request_written_cb, [cb, args])
-        print 'called self.conn.write...'
         
     def __request_written_cb(self, cb, args):
         return cb(*args)
@@ -37,6 +36,8 @@ class HTTPClientRequest(object):
         output = "%s %s %s\r\n" % (self.method, self.path, self.protocol)
         output += "\r\n".join( [": ".join((key, val)) for (key, val) in self.headers.items() ])
         output += "\r\n\r\n"
+        output += self.body.data
+        output += "\r\n\r\n"
         return output
         
 class HTTPClientRawRequest(object):
